pub fn run_validation(
conn: &Connection,
config: &ValidateConfig,
) -> ValidationReportExpand description
Run the full validation suite and return a structured report.
pub fn run_validation(
conn: &Connection,
config: &ValidateConfig,
) -> ValidationReportRun the full validation suite and return a structured report.