pub struct RepairPlan {
pub apply_track_a_rebuild: bool,
pub apply_track_b_rebuild: bool,
pub decisions: Vec<RepairDecision>,
}Expand description
Summary of automatic repair opportunities in a validation report.
Fields
apply_track_a_rebuild: boolapply_track_b_rebuild: boolWhether any Track B check can be repaired by replaying the
token_usage ledger into fresh token_daily_stats via
rebuild_token_daily_stats. Bead m7xrw.
decisions: Vec<RepairDecision>Trait Implementations
Sourceimpl Clone for RepairPlan
impl Clone for RepairPlan
Sourcefn clone(&self) -> RepairPlan
fn clone(&self) -> RepairPlan
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RepairPlan
impl Debug for RepairPlan