file_modified_since

Function file_modified_since 

pub fn file_modified_since(path: &Path, since_ts: Option<i64>) -> bool
Check if a file was modified since the given timestamp. Returns true if the file should be processed (modified since timestamp or no timestamp given).