flatten_content

Function flatten_content 

pub fn flatten_content(val: &Value) -> String
Flatten content that may be a string or array of content blocks. Extracts text from text blocks and tool names from tool_use blocks.