Module client

Module client 

Daemon client for connecting to the semantic model daemon.

This client connects via Unix Domain Socket and provides methods for embedding and reranking. It implements the DaemonClient trait from search::daemon_client for integration with the fallback wrappers.

Structs

DaemonClientConfig
Configuration for the daemon client.
UdsDaemonClient
Unix Domain Socket client for the semantic daemon.

Functions

connect_or_spawn
Connect to an existing daemon or spawn a new one.
try_connect
Try to connect to an existing daemon without spawning.