pub struct UdsDaemonClient { /* private fields */ }Expand description
Unix Domain Socket client for the semantic daemon.
Implementations
Sourceimpl UdsDaemonClient
impl UdsDaemonClient
Sourcepub fn new(config: DaemonClientConfig) -> Self
pub fn new(config: DaemonClientConfig) -> Self
Create a new client with the given configuration.
Sourcepub fn with_defaults() -> Self
pub fn with_defaults() -> Self
Create a client with default configuration.
Sourcepub fn connect(&self) -> Result<(), DaemonError>
pub fn connect(&self) -> Result<(), DaemonError>
Connect to the daemon, optionally spawning it if not running.
Sourcepub fn health(&self) -> Result<HealthStatus, DaemonError>
pub fn health(&self) -> Result<HealthStatus, DaemonError>
Check daemon health.
Sourcepub fn shutdown(&self) -> Result<(), DaemonError>
pub fn shutdown(&self) -> Result<(), DaemonError>
Request daemon shutdown.
Sourcepub fn submit_embedding_job(
&self,
config: EmbeddingJobConfig,
) -> Result<String, DaemonError>
pub fn submit_embedding_job( &self, config: EmbeddingJobConfig, ) -> Result<String, DaemonError>
Submit a background embedding job to the daemon.
Sourcepub fn embedding_job_status(
&self,
db_path: &str,
) -> Result<EmbeddingJobInfo, DaemonError>
pub fn embedding_job_status( &self, db_path: &str, ) -> Result<EmbeddingJobInfo, DaemonError>
Query the status of embedding jobs for a database.
Sourcepub fn cancel_embedding_job(
&self,
db_path: &str,
model_id: Option<&str>,
) -> Result<usize, DaemonError>
pub fn cancel_embedding_job( &self, db_path: &str, model_id: Option<&str>, ) -> Result<usize, DaemonError>
Cancel embedding jobs for a database.