Module worker

Module worker 

Background embedding worker for the daemon.

Processes embedding jobs on a dedicated thread using sync primitives. Adapted from xf’s async worker to cass’s sync daemon architecture.

Structs

EmbeddingJobConfig
Configuration for a single embedding job.
EmbeddingWorker
Background embedding worker that processes jobs on a dedicated thread.
EmbeddingWorkerHandle
Handle for sending messages to the background worker.

Enums

WorkerMessage
Messages sent to the background worker.