pub struct Argon2Params { /* private fields */ }Expand description
Argon2 password hash parameters.
These are parameters which can be encoded into a PHC hash string.
Implementations
Sourceimpl Params
impl Params
Sourcepub const DEFAULT_M_COST: u32
pub const DEFAULT_M_COST: u32
Default memory cost.
Sourcepub const MIN_M_COST: u32
pub const MIN_M_COST: u32
Minimum number of 1 KiB memory blocks.
Sourcepub const MAX_M_COST: u32 = u32::MAX
pub const MAX_M_COST: u32 = u32::MAX
Maximum number of 1 KiB memory blocks.
Sourcepub const DEFAULT_T_COST: u32 = 2
pub const DEFAULT_T_COST: u32 = 2
Default number of iterations (i.e. “time”).
Sourcepub const MIN_T_COST: u32 = 1
pub const MIN_T_COST: u32 = 1
Minimum number of passes.
Sourcepub const MAX_T_COST: u32 = u32::MAX
pub const MAX_T_COST: u32 = u32::MAX
Maximum number of passes.
Sourcepub const DEFAULT_P_COST: u32 = 1
pub const DEFAULT_P_COST: u32 = 1
Default degree of parallelism.
Sourcepub const MIN_P_COST: u32 = 1
pub const MIN_P_COST: u32 = 1
Minimum and maximum number of threads (i.e. parallelism).
Sourcepub const MAX_P_COST: u32 = 0xFFFFFF
pub const MAX_P_COST: u32 = 0xFFFFFF
Minimum and maximum number of threads (i.e. parallelism).
Sourcepub const MAX_KEYID_LEN: usize = 8
pub const MAX_KEYID_LEN: usize = 8
Maximum length of a key ID in bytes.
Sourcepub const MAX_DATA_LEN: usize = 32
pub const MAX_DATA_LEN: usize = 32
Maximum length of associated data in bytes.
Sourcepub const DEFAULT_OUTPUT_LEN: usize = 32
pub const DEFAULT_OUTPUT_LEN: usize = 32
Default output length.
Sourcepub const MIN_OUTPUT_LEN: usize = 4
pub const MIN_OUTPUT_LEN: usize = 4
Minimum digest size in bytes.
Sourcepub const MAX_OUTPUT_LEN: usize = 0xFFFFFFFF
pub const MAX_OUTPUT_LEN: usize = 0xFFFFFFFF
Maximum digest size in bytes.
Sourcepub const fn new(
m_cost: u32,
t_cost: u32,
p_cost: u32,
output_len: Option<usize>,
) -> Result<Params, Error>
pub const fn new( m_cost: u32, t_cost: u32, p_cost: u32, output_len: Option<usize>, ) -> Result<Params, Error>
Create new parameters.
Arguments
m_cost: memory size in 1 KiB blocks. Between 8*p_costand (2^32)-1.t_cost: number of iterations. Between 1 and (2^32)-1.p_cost: degree of parallelism. Between 1 and (2^24)-1.output_len: size of the KDF output in bytes. Default 32.
Sourcepub const fn m_cost(&self) -> u32
pub const fn m_cost(&self) -> u32
Memory size, expressed in kibibytes. Between 8*p_cost and (2^32)-1.
Value is an integer in decimal (1 to 10 digits).
Sourcepub const fn t_cost(&self) -> u32
pub const fn t_cost(&self) -> u32
Number of iterations. Between 1 and (2^32)-1.
Value is an integer in decimal (1 to 10 digits).
Sourcepub const fn p_cost(&self) -> u32
pub const fn p_cost(&self) -> u32
Degree of parallelism. Between 1 and (2^24)-1.
Value is an integer in decimal (1 to 3 digits).
Sourcepub fn keyid(&self) -> &[u8] ⓘ
pub fn keyid(&self) -> &[u8] ⓘ
Key identifier: byte slice between 0 and 8 bytes in length.
Defaults to an empty byte slice.
Note this field is only present as a helper for reading/storing in the PHC hash string format (i.e. it is totally ignored from a cryptographical standpoint).
On top of that, this field is not longer part of the Argon2 standard (see: https://github.com/P-H-C/phc-winner-argon2/pull/173), and should not be used for any non-legacy work.
Sourcepub fn data(&self) -> &[u8] ⓘ
pub fn data(&self) -> &[u8] ⓘ
Associated data: byte slice between 0 and 32 bytes in length.
Defaults to an empty byte slice.
This field is not longer part of the argon2 standard (see: https://github.com/P-H-C/phc-winner-argon2/pull/173), and should not be used for any non-legacy work.
Sourcepub const fn output_len(&self) -> Option<usize>
pub const fn output_len(&self) -> Option<usize>
Length of the output (in bytes).
Sourcepub const fn block_count(&self) -> usize
pub const fn block_count(&self) -> usize
Get the number of blocks required given the configured m_cost and p_cost.