pub enum SwarmCommand {
Status {
json: bool,
fixture: Option<PathBuf>,
fixture_dir: Option<PathBuf>,
fixture_id: String,
},
Evidence {
json: bool,
fixture: Option<PathBuf>,
fixture_dir: Option<PathBuf>,
fixture_id: String,
bead: Option<String>,
},
}Expand description
Read-only swarm operations commands.
Variants
Status
Summarize Beads, Agent Mail, git, build, cass, and evidence state.
Fields
Evidence
Assemble verification evidence for recent commits or a named bead.