pub struct LedgerBuilder { /* private fields */ }Expand description
Builder for incrementally recording phase data during a refresh cycle.
Implementations
Sourceimpl LedgerBuilder
impl LedgerBuilder
Sourcepub fn begin_phase(&mut self, phase: RefreshPhase)
pub fn begin_phase(&mut self, phase: RefreshPhase)
Begin a new phase. Automatically ends any in-progress phase.
Sourcepub fn record_items(&mut self, processed: u64, skipped: u64)
pub fn record_items(&mut self, processed: u64, skipped: u64)
Record items processed in the current phase.
Sourcepub fn record_error(&mut self, message: &str)
pub fn record_error(&mut self, message: &str)
Record a non-fatal error in the current phase.
Multiple errors are joined with “; “ so no diagnostic info is lost.
Sourcepub fn record_failure(&mut self, message: &str)
pub fn record_failure(&mut self, message: &str)
Record a phase failure (the phase did not complete successfully).
This replaces any previous error_message since the failure is the authoritative final state.
Sourcepub fn set_counter(&mut self, key: &str, value: u64)
pub fn set_counter(&mut self, key: &str, value: u64)
Set a custom counter in the current phase.
Sourcepub fn inc_counter(&mut self, key: &str, delta: u64)
pub fn inc_counter(&mut self, key: &str, delta: u64)
Increment a custom counter in the current phase.
Sourcepub fn set_equivalence(&mut self, artifacts: EquivalenceArtifacts)
pub fn set_equivalence(&mut self, artifacts: EquivalenceArtifacts)
Set equivalence artifacts.
Sourcepub fn finish(self) -> RefreshLedger
pub fn finish(self) -> RefreshLedger
Finalize the current phase and the ledger.