pub struct RefreshReadinessMilestones {
pub time_to_lexical_ready_ms: Option<u64>,
pub time_to_search_ready_ms: Option<u64>,
pub time_to_full_settled_ms: Option<u64>,
pub failed_phase: Option<String>,
pub search_readiness_state: RefreshSearchReadinessState,
}Expand description
User-facing readiness timing summary derived from a refresh ledger.
time_to_lexical_ready_ms means the lexical build phase finished
successfully; time_to_search_ready_ms means the publish phase finished
successfully and the refreshed lexical asset is visible to ordinary search.
Fields
time_to_lexical_ready_ms: Option<u64>time_to_search_ready_ms: Option<u64>time_to_full_settled_ms: Option<u64>failed_phase: Option<String>search_readiness_state: RefreshSearchReadinessStateTrait Implementations
Sourceimpl Clone for RefreshReadinessMilestones
impl Clone for RefreshReadinessMilestones
Sourcefn clone(&self) -> RefreshReadinessMilestones
fn clone(&self) -> RefreshReadinessMilestones
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RefreshReadinessMilestones
impl Debug for RefreshReadinessMilestones
Sourceimpl Default for RefreshReadinessMilestones
impl Default for RefreshReadinessMilestones
Sourcefn default() -> RefreshReadinessMilestones
fn default() -> RefreshReadinessMilestones
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for RefreshReadinessMilestones
impl<'de> Deserialize<'de> for RefreshReadinessMilestones
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for RefreshReadinessMilestones
impl PartialEq for RefreshReadinessMilestones
Sourcefn eq(&self, other: &RefreshReadinessMilestones) -> bool
fn eq(&self, other: &RefreshReadinessMilestones) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Eq for RefreshReadinessMilestones
impl StructuralPartialEq for RefreshReadinessMilestones