IndexingStats

Struct IndexingStats 

pub struct IndexingStats {
    pub scan_ms: u64,
    pub index_ms: u64,
    pub connectors: Vec<ConnectorStats>,
    pub agents_discovered: Vec<String>,
    pub total_conversations: usize,
    pub total_messages: usize,
    pub total_counts_exact: bool,
    pub lexical_strategy: Option<String>,
    pub lexical_strategy_reason: Option<String>,
    pub lexical_repair: Option<LexicalRepairStats>,
    pub quarantined_conversations: usize,
    pub lexical_update_deferred: bool,
}
Aggregate indexing statistics for JSON output (T7.4).

Fields

scan_ms: u64

Time spent in scanning phase (ms)

index_ms: u64

Time spent in indexing phase (ms)

connectors: Vec<ConnectorStats>

Per-connector breakdown

agents_discovered: Vec<String>

Agents discovered during scan

total_conversations: usize

Total conversations indexed

total_messages: usize

Total messages indexed

total_counts_exact: boollexical_strategy: Option<String>

Chosen lexical population strategy for this run.

lexical_strategy_reason: Option<String>

Why the lexical population strategy was chosen.

lexical_repair: Option<LexicalRepairStats>

Automatic lexical repair/catch-up performed before normal indexing work.

quarantined_conversations: usize

Conversations skipped by ingest quarantine during this run.

lexical_update_deferred: bool

True when SQLite ingest succeeded but inline lexical updates were deferred and the caller must rebuild lexical assets from the archive.