pub fn count_required_steps(config: &ConfirmationConfig) -> usizeExpand description
Get the number of required steps for the given configuration.
pub fn count_required_steps(config: &ConfirmationConfig) -> usizeGet the number of required steps for the given configuration.