pub struct ConfirmationFlow { /* private fields */ }Expand description
Manages the multi-step confirmation flow.
Implementations
Sourceimpl ConfirmationFlow
impl ConfirmationFlow
Sourcepub fn new(config: ConfirmationConfig) -> Self
pub fn new(config: ConfirmationConfig) -> Self
Create a new confirmation flow with the given configuration.
Sourcepub fn current_step(&self) -> ConfirmationStep
pub fn current_step(&self) -> ConfirmationStep
Get the current step.
Sourcepub fn config(&self) -> &ConfirmationConfig
pub fn config(&self) -> &ConfirmationConfig
Get the configuration.
Sourcepub fn password_action(&self) -> Option<PasswordStrengthAction>
pub fn password_action(&self) -> Option<PasswordStrengthAction>
Get the password action if one was chosen.
Sourcepub fn should_skip_current(&self) -> bool
pub fn should_skip_current(&self) -> bool
Check if the current step should be skipped.
Sourcepub fn validate_secret_ack(&self, input: &str) -> StepValidation
pub fn validate_secret_ack(&self, input: &str) -> StepValidation
Validate input for the secret scan acknowledgment step.
Sourcepub fn validate_content_review(&self, input: &str) -> StepValidation
pub fn validate_content_review(&self, input: &str) -> StepValidation
Validate input for the content review step.
Sourcepub fn validate_public_warning(&self, input: &str) -> StepValidation
pub fn validate_public_warning(&self, input: &str) -> StepValidation
Validate input for the public publishing warning step.
Sourcepub fn parse_password_action(
&self,
input: &str,
) -> Option<PasswordStrengthAction>
pub fn parse_password_action( &self, input: &str, ) -> Option<PasswordStrengthAction>
Parse password strength action from input.
Sourcepub fn validate_recovery_key(&self, input: &str) -> StepValidation
pub fn validate_recovery_key(&self, input: &str) -> StepValidation
Validate input for the recovery key backup step.
Sourcepub fn process_final_enter(&mut self) -> bool
pub fn process_final_enter(&mut self) -> bool
Process an Enter keypress for final confirmation. Returns true if both Enter presses have been received.
Sourcepub fn reset_final_enter(&mut self)
pub fn reset_final_enter(&mut self)
Reset the final Enter counter (e.g., if user typed something else).
Sourcepub fn final_enter_count(&self) -> u8
pub fn final_enter_count(&self) -> u8
Get the number of Enter presses received for final confirmation.
Sourcepub fn complete_current_step(&mut self)
pub fn complete_current_step(&mut self)
Mark the current step as completed and advance to the next.
Sourcepub fn is_complete(&self) -> bool
pub fn is_complete(&self) -> bool
Check if all required steps are completed.
Sourcepub fn set_password_action(&mut self, action: PasswordStrengthAction)
pub fn set_password_action(&mut self, action: PasswordStrengthAction)
Set the password strength action.
Sourcepub fn completed_steps_summary(&self) -> Vec<(ConfirmationStep, &'static str)>
pub fn completed_steps_summary(&self) -> Vec<(ConfirmationStep, &'static str)>
Get the list of completed steps for display.