pub struct EncryptionEngine { /* private fields */ }Expand description
Encryption engine for pages export
Debug is implemented manually to avoid printing the secret DEK.
Implementations
Sourceimpl EncryptionEngine
impl EncryptionEngine
Sourcepub fn add_password_slot(&mut self, password: &str) -> Result<u8>
pub fn add_password_slot(&mut self, password: &str) -> Result<u8>
Add a password-based key slot using Argon2id
Sourcepub fn add_recovery_slot(&mut self, secret: &[u8]) -> Result<u8>
pub fn add_recovery_slot(&mut self, secret: &[u8]) -> Result<u8>
Add a recovery secret slot using HKDF-SHA256
Sourcepub fn key_slot_count(&self) -> usize
pub fn key_slot_count(&self) -> usize
Returns the number of key slots currently configured
Sourcepub fn encrypt_file<P: AsRef<Path>>(
&self,
input: P,
output_dir: P,
progress: impl Fn(u64, u64),
) -> Result<EncryptionConfig>
pub fn encrypt_file<P: AsRef<Path>>( &self, input: P, output_dir: P, progress: impl Fn(u64, u64), ) -> Result<EncryptionConfig>
Encrypt a file with streaming compression and chunked AEAD