Module password

Module password 

Password strength validation and visual feedback.

Provides real-time password strength validation with consistent behavior between CLI (Rust) and browser (JavaScript) implementations.

Strength Levels

LevelEntropyRequirements
Weak<20 bitsMissing multiple requirements
Fair20-40 bitsMissing some requirements
Good40-60 bitsMost requirements met
Strong≥60 bitsAll requirements met, 12+ chars

Structs

PasswordChecks
Individual password requirement checks.
PasswordValidation
Result of password validation.

Enums

PasswordStrength
Password strength levels with associated colors.

Functions

display_strength
Display password strength in the terminal with colored progress bar.
format_strength_inline
Format password strength as a simple inline indicator.
validate_password
Validate a password and return strength assessment with suggestions.