load_semantic_context

Function load_semantic_context 

pub fn load_semantic_context(data_dir: &Path, db_path: &Path) -> SemanticSetup
Load semantic context with optional version mismatch checking.

If check_for_updates is true, this function will check if the installed model version matches the manifest and return UpdateAvailable if they differ.