pub struct SourcesConfig {
pub sources: Vec<SourceDefinition>,
pub disabled_agents: Vec<String>,
}Expand description
Root configuration containing all source definitions.
Fields
sources: Vec<SourceDefinition>List of configured sources.
disabled_agents: Vec<String>Connectors to skip during indexing even if their files exist locally or in configured remote mirrors.
Implementations
Sourceimpl SourcesConfig
impl SourcesConfig
Sourcepub fn load() -> Result<Self, ConfigError>
pub fn load() -> Result<Self, ConfigError>
Load configuration from the default location.
Returns an empty config if the file doesn’t exist.
Sourcepub fn load_from(path: &PathBuf) -> Result<Self, ConfigError>
pub fn load_from(path: &PathBuf) -> Result<Self, ConfigError>
Load configuration from a specific path.
Sourcepub fn save(&self) -> Result<(), ConfigError>
pub fn save(&self) -> Result<(), ConfigError>
Save configuration to the default location.
Sourcepub fn save_to(&self, path: &Path) -> Result<(), ConfigError>
pub fn save_to(&self, path: &Path) -> Result<(), ConfigError>
Save configuration to a specific path.
Sourcepub fn config_path() -> Result<PathBuf, ConfigError>
pub fn config_path() -> Result<PathBuf, ConfigError>
Get the default configuration file path.
Uses XDG conventions:
- Primary:
$XDG_CONFIG_HOME/cass/sources.toml - Fallback: platform-specific config dir (e.g.,
~/.config/cass/sources.tomlon Linux)
Sourcepub fn validate(&self) -> Result<(), ConfigError>
pub fn validate(&self) -> Result<(), ConfigError>
Validate all sources in the configuration.
Sourcepub fn find_source(&self, name: &str) -> Option<&SourceDefinition>
pub fn find_source(&self, name: &str) -> Option<&SourceDefinition>
Find a source by name.
Sourcepub fn find_source_mut(&mut self, name: &str) -> Option<&mut SourceDefinition>
pub fn find_source_mut(&mut self, name: &str) -> Option<&mut SourceDefinition>
Find a source by name (mutable).
Sourcepub fn add_source(
&mut self,
source: SourceDefinition,
) -> Result<(), ConfigError>
pub fn add_source( &mut self, source: SourceDefinition, ) -> Result<(), ConfigError>
Add a new source. Returns error if name already exists.
Sourcepub fn remove_source(&mut self, name: &str) -> bool
pub fn remove_source(&mut self, name: &str) -> bool
Remove a source by name. Returns true if found and removed.
Sourcepub fn remote_sources(&self) -> impl Iterator<Item = &SourceDefinition>
pub fn remote_sources(&self) -> impl Iterator<Item = &SourceDefinition>
Get all remote sources (SSH type).
pub fn configured_disabled_agents(&self) -> Vec<String>
pub fn is_agent_disabled(&self, agent: &str) -> bool
pub fn exclude_agent_from_indexing( &mut self, agent: &str, ) -> Result<bool, ConfigError>
pub fn include_agent_in_indexing( &mut self, agent: &str, ) -> Result<bool, ConfigError>
Sourceimpl SourcesConfig
impl SourcesConfig
Sourcepub fn write_with_backup(&self) -> Result<BackupInfo, ConfigError>
pub fn write_with_backup(&self) -> Result<BackupInfo, ConfigError>
Write configuration with backup.
Creates a uniquely named backup of the existing config (if any) before writing the new configuration atomically.
Sourcepub fn merge_source(
&mut self,
source: SourceDefinition,
) -> Result<MergeResult, ConfigError>
pub fn merge_source( &mut self, source: SourceDefinition, ) -> Result<MergeResult, ConfigError>
Merge a source into the configuration.
Returns MergeResult::Added if the source was added,
or MergeResult::AlreadyExists if a source with the same name exists.
Sourcepub fn merge_preview(
&mut self,
preview: &ConfigPreview,
) -> Result<(usize, Vec<String>), ConfigError>
pub fn merge_preview( &mut self, preview: &ConfigPreview, ) -> Result<(usize, Vec<String>), ConfigError>
Merge multiple sources from a preview.
Returns a tuple of (added_count, skipped_names).
Sourcepub fn configured_names(&self) -> HashSet<String>
pub fn configured_names(&self) -> HashSet<String>
Get set of configured source names.
Sourcepub fn configured_name_keys(&self) -> HashSet<String>
pub fn configured_name_keys(&self) -> HashSet<String>
Get normalized source-name keys for duplicate detection and lookups.