pub struct RemoteArtifactManifestResult {
pub success: bool,
pub manifest_path: Option<String>,
pub bundle_id: Option<String>,
pub chunk_count: Option<usize>,
pub expected_bytes: Option<u64>,
pub verification_status: Option<String>,
pub error: Option<String>,
}Expand description
Result of writing a remote lexical artifact evidence manifest.
Fields
success: boolWhether the proof command completed and produced a complete manifest.
manifest_path: Option<String>Path to evidence-bundle-manifest.json on the remote host.
bundle_id: Option<String>Deterministic content-addressed bundle id.
chunk_count: Option<usize>Number of files described by the manifest.
expected_bytes: Option<u64>Total bytes expected by the evidence report.
verification_status: Option<String>Verification status reported by the remote command.
error: Option<String>Error message when the proof command failed.