pub struct RemoteInstaller { /* private fields */ }Expand description
Installer for cass on remote machines.
Implementations
Sourceimpl RemoteInstaller
impl RemoteInstaller
Sourcepub fn new(
host: impl Into<String>,
system_info: SystemInfo,
resources: ResourceInfo,
) -> Self
pub fn new( host: impl Into<String>, system_info: SystemInfo, resources: ResourceInfo, ) -> Self
Create a new installer for a remote host.
Sourcepub fn with_version(
host: impl Into<String>,
system_info: SystemInfo,
resources: ResourceInfo,
version: impl Into<String>,
) -> Result<Self, InstallError>
pub fn with_version( host: impl Into<String>, system_info: SystemInfo, resources: ResourceInfo, version: impl Into<String>, ) -> Result<Self, InstallError>
Create an installer with a specific target version.
Returns an error if the version string contains characters that are not
safe for shell interpolation (only alphanumeric, ., -, +, _ allowed).
Sourcepub fn target_version(&self) -> &str
pub fn target_version(&self) -> &str
Get the target version.
Sourcepub fn check_resources(&self) -> Result<(), InstallError>
pub fn check_resources(&self) -> Result<(), InstallError>
Check if resources are sufficient for compilation.
Sourcepub fn can_compile(&self) -> Result<(), InstallError>
pub fn can_compile(&self) -> Result<(), InstallError>
Check if resources are sufficient for compilation specifically.
Sourcepub fn choose_method(&self) -> Option<InstallMethod>
pub fn choose_method(&self) -> Option<InstallMethod>
Choose the best installation method based on system info.
Returns None if no viable installation method is available.
Sourcepub fn install<F>(&self, on_progress: F) -> Result<InstallResult, InstallError>
pub fn install<F>(&self, on_progress: F) -> Result<InstallResult, InstallError>
Install cass on the remote host.
Streams progress updates via the callback as installation proceeds.