pub enum SourceSyncAction {
Sync,
Skip,
Defer,
}Expand description
Scheduler action for a remote source.
Variants
Sync
The source is eligible to sync now.
Skip
The source is healthy enough but not due under its configured schedule.
Defer
The source is temporarily or operationally unsafe to sync automatically.
Implementations