pub struct SourceSyncInfo {
pub last_sync: Option<i64>,
pub last_result: SyncResult,
pub files_synced: u64,
pub bytes_transferred: u64,
pub duration_ms: u64,
pub consecutive_failures: u32,
}Expand description
Sync information for a single source.
Fields
last_sync: Option<i64>Timestamp of last sync attempt.
last_result: SyncResultResult of last sync.
files_synced: u64Number of files synced in last sync.
bytes_transferred: u64Number of bytes transferred in last sync.
duration_ms: u64Duration of last sync in milliseconds.
consecutive_failures: u32Consecutive failed sync attempts, reset to zero by a fully successful sync.
Implementations
Sourceimpl SourceSyncInfo
impl SourceSyncInfo
Sourcepub fn from_report(report: &SyncReport) -> Self
pub fn from_report(report: &SyncReport) -> Self
Build sync info from a sync report using the current wall clock time.