create_backup

Function create_backup 

pub fn create_backup(db_path: &Path) -> Result<Option<PathBuf>, MigrationError>
Create a uniquely named backup of the database file.

Returns the path to the backup file, or None if the source doesn’t exist.