pub fn breakdown_rows(data: &AnalyticsChartData, tab: BreakdownTab) -> usizeExpand description
Number of selectable rows in the Breakdowns view for the given tab.
pub fn breakdown_rows(data: &AnalyticsChartData, tab: BreakdownTab) -> usizeNumber of selectable rows in the Breakdowns view for the given tab.