pub fn coverage_row_count(data: &AnalyticsChartData) -> usizeExpand description
Number of visible rows in the Coverage view (for selection bounds).
pub fn coverage_row_count(data: &AnalyticsChartData) -> usizeNumber of visible rows in the Coverage view (for selection bounds).