pub fn tools_row_count(data: &AnalyticsChartData) -> usizeExpand description
Number of visible rows in the Tools view (for selection bounds).
pub fn tools_row_count(data: &AnalyticsChartData) -> usizeNumber of visible rows in the Tools view (for selection bounds).