pub struct UndoHistory {
pub undo_stack: Vec<UndoEntry>,
pub redo_stack: Vec<UndoEntry>,
pub max_depth: usize,
}Expand description
Fixed-capacity undo/redo history.
Fields
undo_stack: Vec<UndoEntry>redo_stack: Vec<UndoEntry>max_depth: usizeImplementations
Sourceimpl UndoHistory
impl UndoHistory
Sourcepub fn pop_undo(&mut self, current: UndoEntry) -> Option<UndoEntry>
pub fn pop_undo(&mut self, current: UndoEntry) -> Option<UndoEntry>
Pop the most recent undo entry, moving current state to redo.
Sourcepub fn pop_redo(&mut self, current: UndoEntry) -> Option<UndoEntry>
pub fn pop_redo(&mut self, current: UndoEntry) -> Option<UndoEntry>
Pop the most recent redo entry, moving current state to undo.
pub fn can_undo(&self) -> bool
pub fn can_redo(&self) -> bool