pub fn execute_selected(state: &PaletteState) -> PaletteResultExpand description
Execute the currently selected palette action, returning a PaletteResult.
Returns PaletteResult::Noop if the palette is empty or selection is out of bounds.
pub fn execute_selected(state: &PaletteState) -> PaletteResultExecute the currently selected palette action, returning a PaletteResult.
Returns PaletteResult::Noop if the palette is empty or selection is out of bounds.