Flex

Struct Flex 

pub struct Flex { /* private fields */ }
A flexible layout container.

Implementations

Source

impl Flex

pub fn vertical() -> Flex

Create a new vertical flex layout.

pub fn horizontal() -> Flex

Create a new horizontal flex layout.

pub fn direction(self, direction: Direction) -> Flex

Set the layout direction.

pub fn constraints( self, constraints: impl IntoIterator<Item = Constraint>, ) -> Flex

Set the constraints.

pub fn margin(self, margin: Sides) -> Flex

Set the margin.

pub fn gap(self, gap: u16) -> Flex

Set the gap between items.

pub fn alignment(self, alignment: Alignment) -> Flex

Set the alignment.

pub fn flow_direction(self, flow: FlowDirection) -> Flex

Set the horizontal flow direction (LTR or RTL).

When set to FlowDirection::Rtl, horizontal layouts are mirrored: the first child appears at the right edge instead of the left. Vertical layouts are not affected.

pub fn overflow(self, overflow: OverflowBehavior) -> Flex

Set the overflow behavior for this container.

pub fn overflow_behavior(&self) -> OverflowBehavior

Get the current overflow behavior.

pub fn constraint_count(&self) -> usize

Number of constraints (and thus output rects from split).

pub fn split(&self, area: Rect) -> SmallVec<[Rect; 8]>

Split the given area into smaller rectangles according to the configuration.

pub fn split_with_measurer<F>( &self, area: Rect, measurer: F, ) -> SmallVec<[Rect; 8]>
where F: Fn(usize, u16) -> LayoutSizeHint,

Split area using intrinsic sizing from a measurer callback.

This method enables content-aware layout with Constraint::FitContent, Constraint::FitContentBounded, and Constraint::FitMin.

Arguments
  • area: Available rectangle
  • measurer: Callback that returns LayoutSizeHint for item at index
Example
let flex = Flex::horizontal()
    .constraints([Constraint::FitContent, Constraint::Fill]);

let rects = flex.split_with_measurer(area, |idx, available| {
    match idx {
        0 => LayoutSizeHint { min: 5, preferred: 20, max: None },
        _ => LayoutSizeHint::ZERO,
    }
});
pub fn split_with_measurer_stably<F>( &self, area: Rect, measurer: F, cache: &mut CoherenceCache, ) -> SmallVec<[Rect; 8]>
where F: Fn(usize, u16) -> LayoutSizeHint,

Split area using intrinsic sizing and temporal coherence.

Combines the content-aware sizing of split_with_measurer with the stability of split_stably.