pub fn spawn_update_check(
current_version: String,
) -> Receiver<Option<UpdateInfo>>Expand description
Start a background thread to check for updates. Returns a receiver that will contain the result when ready.
pub fn spawn_update_check(
current_version: String,
) -> Receiver<Option<UpdateInfo>>Start a background thread to check for updates. Returns a receiver that will contain the result when ready.