Daemon client for connecting to the semantic model daemon.
This client connects via Unix Domain Socket and provides methods for
embedding and reranking. It implements the DaemonClient trait from
search::daemon_client for integration with the fallback wrappers.
Structs
- Daemon
Client Config - Configuration for the daemon client.
- UdsDaemon
Client - Unix Domain Socket client for the semantic daemon.
Functions
- connect_
or_ spawn - Connect to an existing daemon or spawn a new one.
- try_
connect - Try to connect to an existing daemon without spawning.