Function start_preview_server
Source pub async fn start_preview_server(
config: PreviewConfig,
) -> Result<(), PreviewError>
Start the preview server.
This function will block until the server is shut down (via Ctrl+C).
Arguments
config - Server configuration
Returns
Returns Ok(()) on graceful shutdown, or an error if the server fails to start.