pub fn discover_ssh_hosts() -> Vec<DiscoveredHost>Expand description
Discover SSH hosts from ~/.ssh/config.
Parses the SSH config file and returns a list of discovered hosts that could be used as remote sources.
pub fn discover_ssh_hosts() -> Vec<DiscoveredHost>Discover SSH hosts from ~/.ssh/config.
Parses the SSH config file and returns a list of discovered hosts that could be used as remote sources.