execute_selected

Function execute_selected 

pub fn execute_selected(state: &PaletteState) -> PaletteResult
Execute the currently selected palette action, returning a PaletteResult.

Returns PaletteResult::Noop if the palette is empty or selection is out of bounds.